@@ -1,3 +1,4 @@
+import json
 import re
 from typing import Any, DefaultDict, Dict
 
@@ -7,7 +8,7 @@ import WDL as wdl
 class MarkDownNode:
     def __init__(self) -> None:
         self.title = ""
-        self.front_matter = ""
+        self.header = ""
         self.meta = ""
         self.inputs = "\n### Inputs"
         self.outputs = "\n### Outputs"
@@ -15,19 +16,33 @@ class MarkDownNode:
     def set_title(self, title: str) -> None:
         self.title = "\n## " + title + "\n"
 
-    def generate_frontmatter(self, source_text: str) -> None:
+    def generate_header(self, source_text: str) -> None:
         comments = re.findall("^##.*", source_text, re.MULTILINE)
         for comment in comments:
-            self.front_matter += comment[3:] + "\n"
+            self.header += comment[3:] + "\n"
 
     def generate_meta(self, meta: Dict[str, Any]) -> None:
         for key, value in meta.items():
             self.meta += f"\n{key}\n: {value}\n"
 
+    def _parse_description(self, description: str, keys: Dict[str, str]) -> None:
+        if isinstance(description, str):
+            self.inputs += ": {}".format(description)
+            return
+        if keys["description"] in description:
+            self.inputs += ": {}".format(description[keys["description"]])
+            del description[keys["description"]]
+            if keys["choices"] in description:
+                self.inputs += "; **Choices**: {}".format(description[keys["choices"]])
+                del description[keys["choices"]]
+        for key in description:
+            self.inputs += "; **{}**: {}".format(key, description[key])
+
     def generate_inputs(
         self,
         inputs: DefaultDict[str, DefaultDict[str, wdl.Env.Binding]],
         parameter_metadata: Dict[str, Any],
+        keys: Dict[str, str],
     ) -> None:
         if inputs["required"].items():
             self.inputs += "\n\n#### Required\n"
@@ -35,7 +50,7 @@ class MarkDownNode:
             self.inputs += f"\n  * `{name}` ({value.type}, **required**)"
             description = parameter_metadata.get(value.name)
             if description:
-                self.inputs += ": {}".format(description)
+                self._parse_description(description, keys)
 
         if inputs["optional"].items():
             self.inputs += "\n\n#### Optional\n"
@@ -43,7 +58,7 @@ class MarkDownNode:
             self.inputs += f"\n  * `{name}` ({value.type})"
             description = parameter_metadata.get(value.name)
             if description:
-                self.inputs += ": {}".format(description)
+                self._parse_description(description, keys)
 
         if inputs["default"].items():
             self.inputs += "\n\n#### Defaults\n"
@@ -51,7 +66,7 @@ class MarkDownNode:
             self.inputs += f"\n  * `{name}` ({value.type}, default={value.expr})"
             description = parameter_metadata.get(value.name)
             if description:
-                self.inputs += ": {}".format(description)
+                self._parse_description(description, keys)
 
         if self.inputs == "\n### Inputs":
             self.inputs += "\n**None**\n"
